CREATE TABLE TDSP_ESIID
(
  ESIID                VARCHAR2(100),
  ADDRESS              VARCHAR2(200),
  ADDRESS_OVERFLOW     VARCHAR2(100),
  CITY                 VARCHAR2(50),
  STATE                VARCHAR2(10),
  ZIPCODE              VARCHAR2(30),
  DUNS                 VARCHAR2(30),
  METER_READ_CYCLE     VARCHAR2(30),
  STATUS               VARCHAR2(30),
  PREMISE_TYPE         VARCHAR2(30),
  POWER_REGION         VARCHAR2(30),
  STATIONCODE          VARCHAR2(64),
  STATIONNAME          VARCHAR2(64),
  METERED              VARCHAR2(10),
  OPEN_SERVICE_ORDERS  VARCHAR2(2000),
  POLR_CUSTOMER_CLASS     VARCHAR2(30),
  SETTLEMENT_AMS_INDICATOR  	VARCHAR2(1),
  TDSP_AMS_INDICATOR		VARCHAR2(30),
  SWITCH_HOLD_INDICATOR  	CHAR(1));

COMMENT ON TABLE TDSP_ESIID IS 'Table that stores the addresses for the accounts (ESIIDs etc...)';

COMMENT ON COLUMN TDSP_ESIID.ESIID IS 'The Electric Service Industry Identifier (ESIID) as assigned by the TDSP';

COMMENT ON COLUMN TDSP_ESIID.ADDRESS IS 'Registered Street Address ex: SEA BREEZE TANK STA';

COMMENT ON COLUMN TDSP_ESIID.ADDRESS_OVERFLOW IS 'Address Overflow information - if necessary';

COMMENT ON COLUMN TDSP_ESIID.CITY IS 'Registered City ex: WINNIE';

COMMENT ON COLUMN TDSP_ESIID.STATE IS 'Registered State ex: TX';

COMMENT ON COLUMN TDSP_ESIID.ZIPCODE IS 'Registered Zip Code ex: 77665';

COMMENT ON COLUMN TDSP_ESIID.DUNS IS 'This code uniquely identifies the market participant as registered at ERCOT';

COMMENT ON COLUMN TDSP_ESIID.METER_READ_CYCLE IS 'Structure Type ex: 03';

COMMENT ON COLUMN TDSP_ESIID.STATUS IS 'Status of the organization account ex: Active';

COMMENT ON COLUMN TDSP_ESIID.PREMISE_TYPE IS 'Denotes the type of premise as either Residential, Small Non-Residential, or Large Non-Residential.';

COMMENT ON COLUMN TDSP_ESIID.POWER_REGION IS 'The unique character code identifying the power region the ESIID is electrically connected in as assigned by the TDSP (ERCOT, SPP, SERC, WSCC).';

COMMENT ON COLUMN TDSP_ESIID.STATIONCODE IS 'The unique character code to identify a substation serving an ESIID as assigned by the TDSP and used in the ERCOT Network Model.';

COMMENT ON COLUMN TDSP_ESIID.STATIONNAME IS 'The long name to identify a substation used in the ERCOT Network Model.';

COMMENT ON COLUMN TDSP_ESIID.METERED IS 'The derivation of the PROFILETYPE of the PROFILECODE. If the PROFILETYPE is = NM, the data would show N for not metered. If the PROFILETYPE is <> NM, the data would show Y for metered.';

COMMENT ON COLUMN TDSP_ESIID.OPEN_SERVICE_ORDERS IS 'Concatenation of all pending service orders by pipe (|) that includes the service order type and scheduled date. ';

COMMENT ON COLUMN TDSP_ESIID.POLR_CUSTOMER_CLASS IS 'POLR Customer Class';

COMMENT ON COLUMN TDSP_ESIID.SETTLEMENT_AMS_INDICATOR IS 'The flag to identify if the meter is an advanced meter.''Y''=AMS meter,''N''= not AMS meter';

COMMENT ON COLUMN TDSP_ESIID.TDSP_AMS_INDICATOR IS 'Indicates the ESIID has a provisioned AMS meter.  AMSM = TDSP provisioned AMS meter without remote connect and disconnect capability, AMSR = TDSP provisioned AMS meter with remote connect and disconnect capability. NULL = either a Non AMS meter, a non-provisioned AMS meter or unmetered.';

COMMENT ON COLUMN TDSP_ESIID.SWITCH_HOLD_INDICATOR IS 'The indicator to identify if there are Switch Holds present at ERCOT .''Y''=Switch Hold present,''N''= No Switch Hold present';
